pub struct Output {
pub activated: bool,
pub expected_blobs: i64,
pub imported_blobs: i64,
pub indexed_records: i64,
pub private_state_values: i64,
pub repo_blocks: i64,
pub repo_commit: String,
pub repo_rev: String,
pub valid_did: bool,
}Expand description
Returns the status of an account, especially as pertaining to import or recovery. Can be called many times over the course of an account migration. Requires auth and can only be called pertaining to oneself. XRPC Query: com.atproto.server.checkAccountStatus
Fields
activated: boolexpected_blobs: i64imported_blobs: i64indexed_records: i64private_state_values: i64repo_blocks: i64repo_commit: Stringrepo_rev: Stringvalid_did: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Output
impl<'de> Deserialize<'de> for Output
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more