pub struct Input {
pub delete_after: Option<String>,
}Expand description
Deactivates a currently active account. Stops serving of repo, and future writes to repo until reactivated. Used to finalize account migration with the old host after the account has been activated on the new host. XRPC Procedure: com.atproto.server.deactivateAccount
Fields
delete_after: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Input
impl<'de> Deserialize<'de> for Input
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more