pub struct Input {
pub did: Option<String>,
}Expand description
Reserve a repo signing key, for use with account creation. Necessary so that a DID PLC update operation can be constructed during an account migraiton. Public and does not require auth; implemented by PDS. NOTE: this endpoint may change when full account migration is implemented. XRPC Procedure: com.atproto.server.reserveSigningKey
Fields
did: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Input
impl<'de> Deserialize<'de> for Input
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more