pub struct Input {
pub hostname: String,
}Expand description
Notify a crawling service of a recent update, and that crawling should resume. Intended use is after a gap between repo stream events caused the crawling service to disconnect. Does not require auth; implemented by Relay. DEPRECATED: just use com.atproto.sync.requestCrawl XRPC Procedure: com.atproto.sync.notifyOfUpdate
Fields
hostname: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Input
impl<'de> Deserialize<'de> for Input
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more