pub struct Commit {
pub blobs: Vec<Cid>,
pub blocks: Vec<u8>,
pub commit: Cid,
pub ops: Vec<RepoOp>,
pub prev_data: Option<Cid>,
pub rebase: bool,
pub repo: String,
pub rev: String,
pub seq: i64,
pub since: Option<String>,
pub time: String,
pub too_big: bool,
}Expand description
Represents an update of repository state. Note that empty commits are allowed, which include no repo data changes, but an update to rev and signature.
Fields
blobs: Vec<Cid>blocks: Vec<u8>commit: Cidops: Vec<RepoOp>prev_data: Option<Cid>rebase: boolrepo: Stringrev: Stringseq: i64since: Option<String>time: Stringtoo_big: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Commit
impl<'de> Deserialize<'de> for Commit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more