pub struct Input {
pub name: String,
pub values: Vec<String>,
}Expand description
Delete values from a specific set. Attempting to delete values that are not in the set will not result in an error XRPC Procedure: tools.ozone.set.deleteValues
Fields
name: Stringvalues: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Input
impl<'de> Deserialize<'de> for Input
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more